@@ -68,8 +68,8 @@ sub _load_modules {
 		$self->raiseError($@) && die $@ if $@;
 		$module = $module->[1]->new(app => 1);
 		die $@ && next if $@;
-		my $namespace = $module->namespace;
-		$mods{$namespace} = $module;
+		$mods{_alias}{$module->capture} = $module->namespace if $module->{capture}; 	
+		$mods{$module->namespace} = $module;
 	}
 	return \%mods;
 }
@@ -108,17 +108,25 @@ sub preprocess_req {
 sub dispatch {
 	my ($self, $req, $t, @params) = @_;
 	(my $path = $t->request->uri->path) =~ s/^\///g;
-	if ($path && ! $self->controllers->{$path}) {
+	my $controller = $t->controller($path);
+	if ($path && ! $controller) {
 		$t->logError('Path not found - ' . $path, 500);
 		return;
 	}
 	if ($req eq $t->{_auth} || $t->is_login || $t->is_logout) {
 		my @response = $self->SUPER::dispatch($req, $t, @params);
-		@response = $self->controllers->{$path}->dispatch($req, $t, @response)
-			if $path && $self->{controllers}->{$path}->can($req);
+		@response = $controller->dispatch($req, $t, @response)
+			if $path && $controller->can($req);
 		return @response;
 	} elsif ($path) {
-		return $self->controllers->{$path}->dispatch($req, $t, @params);
+		if ($controller->required_captured && scalar @{$t->captured ||= []} != $controller->required_captured) {
+			$t->logError('Missing captured arguments', 500);
+			return;
+		}
+		if ($controller->default_req && !$t->params->req) {
+			$req = $controller->default_req;
+		}
+		return $controller->dispatch($req, $t, @params);
 	}
 	return $self->SUPER::dispatch($req, $t, @params);
 }
@@ -134,7 +142,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.102
+Version 0.103
 
 =cut
 
@@ -178,7 +186,14 @@ Version 0.102
 
 	use base 'Terse::Controller';
 
+	sub build_controller {
+		$_[0]->required_captured = 2;
+		$_[0]->capture = 'hello/(.*)/world/(.*)';
+		$_[0];
+	}
+
 	sub world :get {
+		$_[1]->respone->captured = $_[1]->captured;
 		... #3
 	}
 
@@ -202,7 +217,7 @@ Version 0.102
 
 	GET http://localhost:5000/hello?id=here&other=params #1
 	GET http://localhost:5000/hello?req=world #2
-	GET http://localhost:5000/hello/world #3
+	GET http://localhost:5000/hello/abc/world/123 #3
 
 =cut
 
