@@ -18,6 +18,7 @@ sub new {
 	(my $namespace = $pkg) =~ s/^.*Controller:://;
 	$namespace =~ s/\:\:/\//g;
 	$self->namespace = lc( $namespace );
+	$self->default_req = [split "/", $self->namespace]->[-1];
 	$self->build_controller() if ($self->can('build_controller'));
 	return $self;
 }
@@ -34,8 +35,17 @@ sub build_terse {
 	if ($self->controllers) {
 		$t->{controller} = sub {
 			my ($t, $controller) = @_;
-			$t->raiseError("invalid controller: ${controller}", 400) unless $self->controllers->{$controller};
-			return $t->controllers->{$controller};
+
+			return $self->controllers->{$controller} if $self->controllers->{$controller};
+			for my $key (keys %{$self->controllers->{_alias}}) {
+				my @captured = $controller =~ m/$key/;
+				if (scalar @captured) {
+					$controller = $self->controllers->{$self->controllers->{_alias}->{$key}};
+					$t->captured = \@captured;
+					return $controller;
+				}
+			}
+			return;
 		};
 	}
 	if ($self->views) {
@@ -165,7 +175,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.102
+Version 0.103
 
 =cut
 
