@@ -24,7 +24,7 @@ Terse::View - views made simple.
 
 =head1 VERSION
 
-Version 0.102
+Version 0.103
 
 =cut
 
@@ -47,7 +47,8 @@ Version 0.102
 	}
 
 	sub auth {
-		$c->controller('admin/auth')->authenticate(@_);
+		shift;
+		$_[0]->controller('admin/auth')->authenticate(@_);
 	}
 
 	... else 
