@@ -4,7 +4,8 @@ use base 'Terse::Controller';
 
 sub build_controller {
 	my ($self) = @_;
-	#$self->namespace = 'stock';
+	$self->required_captured = 2;
+	$self->capture = 'app/(.*)/hello/(.*)';
 	return $self;
 }
 
@@ -13,6 +14,7 @@ sub hidden {
 }
 
 sub hello :get {
+	$_[1]->response->captured = $_[1]->captured;
 	$_[1]->response->hello = $_[1]->model('test')->something();
 }
 
